@@ -8,12 +8,12 @@
 #' during the \emph{j}th time interval on day \emph{i}. This dataset has been analyzed in several
 #' prior studies; e.g. Brown et al. (2005),  Shen and Huang
 #' (2005), Huang et al. (2008), and Maadooliat et al. (2015). Here, the data are aggregated  into time
-#' intervals 6 minutes.
+#' intervals of 6 minutes. The data is hosted on GitHub and \code{\link{load_github_data}} may be used to load the data.
 #' @name Callcenter
 #' @format A dataframe with 87600 rows and 5 variables:
 #' \describe{
 #'   \item{calls}{The number of calls in 6 minutes aggregated interval.}
-#'   \item{u}{a numeric vector to show the aggregated interval.}
+#'   \item{u}{A numeric vector to show the aggregated interval.}
 #'   \item{Date}{Date time when the calls counts are recorded}.
 #'   \item{Day}{Weekday associated with Date.}
 #'   \item{Month}{Month associated with Date.}
@@ -39,8 +39,5 @@
 #'   components analysis. \emph{Journal of Computational and
 #'   Graphical Statistics}, \strong{24}(1), 84-103.
 #' }
-#' @source \url{http://iew3.technion.ac.il/serveng/callcenterdata/index.html}
 #' @seealso \code{\link{fssa}}
-"Callcenter"
-
-
+NULL
